import { NextResponse } from "next/server";
import pool from "@/utils/db";

export async function POST(request: Request) {
  let runId;
  try {
    let {
      runName,
      testName,
      path,
      success,
      runId: passedRunId,
      runType = "start"
    } = await request.json();

    let pending;
    if (!passedRunId) {
      const res = await pool
        .query(
          `WITH new_run AS (
          INSERT INTO runs (name)
          VALUES ($1)
          RETURNING id
        )
        SELECT id FROM new_run;`,
          [runName]
        )
        .then((r) => r.rows[0].id);

        return NextResponse.json({runId: res})
    }

    // create as Pending by default, then update and add the duration from the passed information
    // can likely remove runType as a whole? 


    if (runType === "end") pending = false;
    else pending = true;


    // Now create the test run entry with 'pending' status
    if (passedRunId) {
      await pool.query(
        `INSERT INTO test_runs (run_id, test_name, path, run_type, created_at, success, pending)
         VALUES ($1, $2, $3, $4, NOW(), $5, $6);`,
        [passedRunId, testName, path, runType, success, pending]
      );
    }

    return NextResponse.json({ runId });
  } catch (error) {
    console.error("Error creating run:", error);
    return NextResponse.json(
      {
        error: "Failed to create run",
        // @ts-ignore
        message: error.message,
        // @ts-ignore
        detail: error.detail,
      },
      { status: 500 }
    );
  }
}
